resultx library

Support for doing something awesome.

More dartdocs go here.

Classes

Error<S, E>
Represents a failed result containing an error of type E.
Result<S, E>
A sealed class representing the result of an operation that can either succeed or fail.
Success<S, E>
Represents a successful result containing data of type S.

Extensions

FtrResultExt on FtrResult<S, E>
Extension methods for FtrResult to provide convenient asynchronous operations. This extension allows chaining operations on Future
FtrSuccessExt on Future<Success<S, E>>
Extension methods for Future

Typedefs

FtrError<S, E> = Future<Result<S, E>>
A convenience typedef for a Future that resolves to an error Result. This represents an asynchronous operation that is expected to fail with error type E.
FtrResult<S, E> = Future<Result<S, E>>
A convenience typedef for a Future that resolves to a Result. This represents an asynchronous operation that can either succeed with type S or fail with error type E.
FtrSuccess<S, E> = Future<Result<S, E>>
A convenience typedef for a Future that resolves to a successful Result. This represents an asynchronous operation that is expected to succeed with type S.