FtrError<S, E> typedef

FtrError<S, E> = Future<Result<S, E>>

A convenience typedef for a Future that resolves to an error Result. This represents an asynchronous operation that is expected to fail with error type E.

Implementation

typedef FtrError<S, E> = Future<Result<S, E>>;