FtrSuccess<S, E> typedef

FtrSuccess<S, E> = Future<Result<S, E>>

A convenience typedef for a Future that resolves to a successful Result. This represents an asynchronous operation that is expected to succeed with type S.

Implementation

typedef FtrSuccess<S, E> = Future<Result<S, E>>;