FtrResult<S, E> typedef
A convenience typedef for a Future that resolves to a Result.
This represents an asynchronous operation that can either succeed with type S or fail with error type E.
Implementation
typedef FtrResult<S, E> = Future<Result<S, E>>;